import { Grid, IconButton, Stack } from "@mui/material";
import ArrowBackIcon from "@mui/icons-material/ArrowBack";
import { useContext, useEffect, useState } from "react";
import { useNavigate } from "react-router-dom";
import {
  GlobalAppBarContext,
  useIsCurrentUserPermitted,
  TabPanel
} from "@ess-ics/ce-ui-common";
import { IOCLiveStatus } from "../../components/IOC/IOCLiveStatus";
import { IOCManage } from "../../components/IOC/IOCManage";
import { IOCAdmin } from "../../components/IOC/IOCAdmin";
import { applicationTitle } from "../../components/common/Helper";

export function IOCDetailsView({ ioc }) {
  const [tabIndex, setTabIndex] = useState(0);
  const { setTitle } = useContext(GlobalAppBarContext);
  const navigate = useNavigate();

  useEffect(() => {
    if (ioc) {
      setTitle(applicationTitle(`IOC Details: ${ioc.namingName}`));
    }
  }, [ioc, setTitle]);

  const tabs = [
    {
      label: "Status",
      content: <IOCLiveStatus ioc={ioc} />
    }
  ];

  const isPermittedManagement = useIsCurrentUserPermitted({
    allowedRoles: ["DeploymentToolAdmin", "DeploymentToolIntegrator"]
  });

  const isPermittedAdmin = useIsCurrentUserPermitted({
    allowedRoles: ["DeploymentToolAdmin"]
  });

  if (isPermittedManagement) {
    tabs.push({
      label: "Management",
      content: <IOCManage ioc={ioc} />
    });
  }
  if (isPermittedAdmin) {
    tabs.push({
      label: "Admin",
      content: <IOCAdmin ioc={ioc} />
    });
  }

  return (
    <Grid
      container
      spacing={1}
    >
      <Grid
        item
        xs={12}
        style={{ paddingBottom: 0 }}
      >
        <TabPanel
          tabs={tabs}
          initialIndex={tabIndex}
          onTabChange={(index) => setTabIndex(index)}
          TabsProps={{ centered: true, sx: { flex: 1 } }}
          renderTabs={(tabs) => (
            <Stack
              flexDirection="row"
              justifyContent="space-between"
            >
              <IconButton
                color="inherit"
                onClick={() => navigate(-1)}
                size="large"
              >
                <ArrowBackIcon />
              </IconButton>
              {tabs}
            </Stack>
          )}
        />
      </Grid>
    </Grid>
  );
}
